public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
From: "J.A. Magallon" <jamagallon@able.es>
To: Jeff Garzik <jgarzik@pobox.com>
Cc: marcelo@conectiva.com.br, linux-kernel@vger.kernel.org
Subject: Re: [bk patches] 2.4.x quick fixes
Date: Mon, 1 Sep 2003 00:06:02 +0200	[thread overview]
Message-ID: <20030831220602.GA2465@werewolf.able.es> (raw)
In-Reply-To: <20030831140543.GA4819@gtf.org>; from jgarzik@pobox.com on Sun, Aug 31, 2003 at 16:05:43 +0200


On 08.31, Jeff Garzik wrote:
> 
> Marcelo, please do a
> 
> 	bk pull bk://kernel.bkbits.net/jgarzik/misc-2.4
> 
> This will update the following files:
> 
>  arch/i386/kernel/pci-irq.c |    1 +
>  drivers/pci/pci.c          |    2 +-
>  include/linux/pci.h        |    2 +-
>  3 files changed, 3 insertions(+), 2 deletions(-)
> 

Against pre2, this is missing to build the thing:

--- linux-2.4.23-pre2-jam1m/drivers/pci/pci.c.orig	2003-08-31 23:59:15.000000000 +0200
+++ linux-2.4.23-pre2-jam1m/drivers/pci/pci.c	2003-09-01 00:00:22.000000000 +0200
@@ -908,7 +908,7 @@
 }
 
 /**
  * pdev_set_mwi - arch helper function for pcibios_set_mwi
  * @dev: the PCI device for which MWI is enabled
  *
  * Helper function for implementation the arch-specific pcibios_set_mwi
@@ -918,7 +918,7 @@
  * RETURNS: An appriopriate -ERRNO error value on eror, or zero for success.
  */
 int
-pdev_set_mwi(struct pci_dev *dev)
+pci_generic_prep_mwi(struct pci_dev *dev)
 {
 	int rc = 0;
 	u8 cache_size;
@@ -966,7 +966,7 @@
 #ifdef HAVE_ARCH_PCI_MWI
 	rc = pcibios_set_mwi(dev);
 #else
-	rc = pdev_set_mwi(dev);
+	rc = pci_generic_prep_mwi(dev);
 #endif
 
 	if (rc)
@@ -908,7 +908,7 @@
 
 /**
- * pdev_set_mwi - arch helper function for pcibios_set_mwi
+ * pci_generic_prep_mwi - arch helper function for pcibios_set_mwi
  * @dev: the PCI device for which MWI is enabled
  *

-- 
J.A. Magallon <jamagallon@able.es>      \                 Software is like sex:
werewolf.able.es                         \           It's better when it's free
Mandrake Linux release 9.2 (Cooker) for i586
Linux 2.4.23-pre2-jam1m (gcc 3.3.1 (Mandrake Linux 9.2 3.3.1-1mdk))

  reply	other threads:[~2003-08-31 22:06 UTC|newest]

Thread overview: 3+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2003-08-31 14:05 [bk patches] 2.4.x quick fixes Jeff Garzik
2003-08-31 22:06 ` J.A. Magallon [this message]
2003-09-03 17:01   ` Jeff Garzik

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20030831220602.GA2465@werewolf.able.es \
    --to=jamagallon@able.es \
    --cc=jgarzik@pobox.com \
    --cc=linux-kernel@vger.kernel.org \
    --cc=marcelo@conectiva.com.br \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox